Package 'MEsreg'

Title: Generalized Maximum entropy for fitting smooth transition regression
Description: This package provides the GME estimation for linear regression and smooth transition regression models
Authors: Dr.Woraphon Yamaka
Maintainer: The package maintainer <[email protected]>
License: COEE.07
Version: 0.1.0
Built: 2026-06-07 09:05:02 UTC
Source: https://github.com/woraphonyamaka/mesreg

Help Index


Generalized Maximum Entropy for estimating linear regression.

Description

This function is used to estimate the linear gression model using GME.

Usage

MEregress(y,x,number,Z,V)

Arguments

y

dependent variable

x

One dimension of dependent variable

number

number of supports i.e. "3", "5" and "7

Z

bound of coefficient

V

bound of error

Details

This funciton is used to estimated the linear regression

Value

beta

intercept,beta

Maxent

Maximum entropy

Author(s)

Dr.Woraphon Yamaka

References

Golan, A., Judge, G. G., & Miller, D. (1996). Maximum entropy econometrics. Iowa State University, Department of Economics.

Jaynes, E. T. (1957). Information theory and statistical mechanics. Physical review, 106(4), 620.

Maneejuk, P., Yamaka, W., & Sriboonchitta, S. (2019). Does the Kuznets curve exist in Thailand? A two decades’ perspective (1993–2015). Annals of Operations Research, 1-32.

Maneejuk, P. and Yamaka, W. (2020). Entropy Inference in Smooth Transition Kink Regression

Examples

library("Rsolnp")
set.seed(1)
n=100
e=rnorm(n)
x0=rnorm(n)
x1=rnorm(n)
y=1+2*x0+3*x1+e
x=cbind(x0,x1)
MEregress(y,x,number="3",Z=10,V=5)

Generalized Maximum Entropy for estimating the smooth transition kink regression

Description

GME inference method for the smooth transition kink regression model with under kink point. The advantage of GME method is that it is robust even when we have ill-posed or ill-conditioned problems, and thus, it has higher estimation accuracy and robustness, especially when the probability distribution of errors is unknown.

Usage

MEskink(y,x,number,Z,V)

Arguments

y

dependent variable

x

One dimension of dependent variable

number

number of supports i.e. "3", "5" and "7

Z

bound of coefficient

V

bound of error

Details

Entropy refers to the amount of uncertainty represented by a discrete probability distribution. The maximum entropy method was proposed by Jaynes (1957) and developed in the early 1990s by Golan, Judge, and Miller (1996) for estimating the unknown probabilities of a discrete probability distribution. This estimator uses the entropy-information measure of Shannon (1948) to recover those unknown probability distributions of underdetermined problems. This function is a simple estimation function for one covariate.

Value

beta

intercept,beta_regime1,beta_regime2

threshold

kink point

smooth

smooth parameter

Maxent

Maximum entropy

Author(s)

Dr.Woraphon Yamaka

References

Golan, A., Judge, G. G., & Miller, D. (1996). Maximum entropy econometrics. Iowa State University, Department of Economics.

Jaynes, E. T. (1957). Information theory and statistical mechanics. Physical review, 106(4), 620.

Maneejuk, P., Yamaka, W., & Sriboonchitta, S. (2019). Does the Kuznets curve exist in Thailand? A two decades’ perspective (1993–2015). Annals of Operations Research, 1-32.

Maneejuk, P. and Yamaka, W. (2020). Entropy Inference in Smooth Transition Kink Regression

Examples

library("Rsolnp")
set.seed(1)
n=100
thres=3
gam=1.2
e=rnorm(n)
x=rnorm(n,thres,5)
alpha=c(0.5,1,-1)

y=alpha[1]+(alpha[2]*(x*(1-logis(gam,x,thres))))+(alpha[3]*(x*(logis(gam,x,thres))))+e

MEskink(y,x,number="5",Z=10,V=5)